@@ -1,29 +1,17 @@
-/******************************************************************************
- *                       ____    _    _____                                   *
- *                      / ___|  / \  |  ___|    C++                           *
- *                     | |     / _ \ | |_       Actor                         *
- *                     | |___ / ___ \|  _|      Framework                     *
- *                      \____/_/   \_|_|                                      *
- *                                                                            *
- * Copyright 2011-2018 Dominik Charousset                                     *
- *                                                                            *
- * Distributed under the terms and conditions of the BSD 3-Clause License or  *
- * (at your option) under the terms and conditions of the Boost Software      *
- * License 1.0. See accompanying files LICENSE and LICENSE_ALTERNATIVE.       *
- *                                                                            *
- * If you did not receive a copy of the license files, see                    *
- * http://opensource.org/licenses/BSD-3-Clause and                            *
- * http://www.boost.org/LICENSE_1_0.txt.                                      *
- ******************************************************************************/
+// This file is part of CAF, the C++ Actor Framework. See the file LICENSE in
+// the main distribution directory for license terms and copyright or visit
+// https://github.com/actor-framework/actor-framework/blob/master/LICENSE.
 
 #pragma once
 
 #include <type_traits>
 
 #include "caf/all.hpp"
+#include "caf/binary_serializer.hpp"
+#include "caf/byte_buffer.hpp"
 #include "caf/config.hpp"
 #include "caf/detail/gcd.hpp"
-#include "caf/meta/annotation.hpp"
+#include "caf/init_global_meta_objects.hpp"
 #include "caf/test/unit_test.hpp"
 
 CAF_PUSH_WARNINGS
@@ -230,9 +218,11 @@ private:
 template <class... Ts>
 caf::optional<std::tuple<Ts...>> default_extract(caf_handle x) {
   auto ptr = x->peek_at_next_mailbox_element();
-  if (ptr == nullptr || !ptr->content().template match_elements<Ts...>())
+  if (ptr == nullptr)
     return caf::none;
-  return ptr->content().template get_as_tuple<Ts...>();
+  if (auto view = caf::make_const_typed_message_view<Ts...>(ptr->content()))
+    return to_tuple(view);
+  return caf::none;
 }
 
 /// @private
@@ -451,25 +441,26 @@ public:
   }
 
   void with(Ts... xs) {
-    if (src_ == nullptr)
-      CAF_FAIL("missing .from() in inject() statement");
     if (dest_ == nullptr)
       CAF_FAIL("missing .to() in inject() statement");
-    caf::send_as(caf::actor_cast<caf::actor>(src_),
-                 caf::actor_cast<caf::actor>(dest_), xs...);
-    CAF_REQUIRE(sched_.prioritize(dest_));
+    auto msg = caf::make_message(std::move(xs)...);
+    if (src_ == nullptr)
+      caf::anon_send(caf::actor_cast<caf::actor>(dest_), msg);
+    else
+      caf::send_as(caf::actor_cast<caf::actor>(src_),
+                   caf::actor_cast<caf::actor>(dest_), msg);
+    if (!sched_.prioritize(dest_))
+      CAF_FAIL("inject: failed to schedule destination actor");
     auto dest_ptr = &sched_.next_job<caf::abstract_actor>();
     auto ptr = dest_ptr->peek_at_next_mailbox_element();
-    CAF_REQUIRE(ptr != nullptr);
-    CAF_REQUIRE_EQUAL(ptr->sender, src_);
-    // TODO: replace this workaround with the make_tuple() line when dropping
-    //       support for GCC 4.8.
-    std::tuple<Ts...> tmp{std::move(xs)...};
-    using namespace caf::detail;
-    elementwise_compare_inspector<decltype(tmp)> inspector{tmp};
-    auto ys = extract<Ts...>(dest_);
-    auto ys_indices = get_indices(ys);
-    CAF_REQUIRE(apply_args(inspector, ys_indices, ys));
+    if (ptr == nullptr)
+      CAF_FAIL("inject: failed to get next message from destination actor");
+    if (ptr->sender != src_)
+      CAF_FAIL("inject: found unexpected sender for the next message");
+    if (ptr->payload.cptr() != msg.cptr())
+      CAF_FAIL("inject: found unexpected message => " << ptr->payload << " !! "
+                                                      << msg);
+    msg.reset(); // drop local reference before running the actor
     run_once();
   }
 
@@ -635,27 +626,23 @@ protected:
 
 template <class... Ts>
 struct test_coordinator_fixture_fetch_helper {
-  template <class Self, class Interface>
+  template <class Self, template <class> class Policy, class Interface>
   std::tuple<Ts...>
-  operator()(caf::response_handle<Self, Interface, true>& from) const {
+  operator()(caf::response_handle<Self, Policy<Interface>>& from) const {
     std::tuple<Ts...> result;
     from.receive([&](Ts&... xs) { result = std::make_tuple(std::move(xs)...); },
-                 [&](caf::error& err) {
-                   FAIL(from.self()->system().render(err));
-                 });
+                 [&](caf::error& err) { CAF_FAIL(err); });
     return result;
   }
 };
 
 template <class T>
 struct test_coordinator_fixture_fetch_helper<T> {
-  template <class Self, class Interface>
-  T operator()(caf::response_handle<Self, Interface, true>& from) const {
+  template <class Self, template <class> class Policy, class Interface>
+  T operator()(caf::response_handle<Self, Policy<Interface>>& from) const {
     T result;
     from.receive([&](T& x) { result = std::move(x); },
-                 [&](caf::error& err) {
-                   FAIL(from.self()->system().render(err));
-                 });
+                 [&](caf::error& err) { CAF_FAIL(err); });
     return result;
   }
 };
@@ -669,21 +656,22 @@ public:
   /// A deterministic scheduler type.
   using scheduler_type = caf::scheduler::test_coordinator;
 
-  /// A buffer for serializing or deserializing objects.
-  using byte_buffer = std::vector<char>;
-
   // -- constructors, destructors, and assignment operators --------------------
 
   static Config& init_config(Config& cfg) {
-    cfg.set("logger.file-verbosity", caf::atom("quiet"));
     if (auto err = cfg.parse(caf::test::engine::argc(),
                              caf::test::engine::argv()))
       CAF_FAIL("failed to parse config: " << to_string(err));
-    cfg.set("scheduler.policy", caf::atom("testing"));
-    cfg.set("logger.inline-output", true);
-    cfg.set("middleman.network-backend", caf::atom("testing"));
-    cfg.set("middleman.manual-multiplexing", true);
-    cfg.set("middleman.workers", size_t{0});
+    cfg.set("caf.scheduler.policy", "testing");
+    cfg.set("caf.logger.inline-output", true);
+    if (cfg.custom_options().has_category("caf.middleman")) {
+      cfg.set("caf.middleman.network-backend", "testing");
+      cfg.set("caf.middleman.manual-multiplexing", true);
+      cfg.set("caf.middleman.workers", size_t{0});
+    }
+    cfg.set("caf.stream.credit-policy", "token-based");
+    cfg.set("caf.stream.token-based-policy.batch-size", 50);
+    cfg.set("caf.stream.token-based-policy.buffer-size", 200);
     return cfg;
   }
 
@@ -693,9 +681,6 @@ public:
       sys(init_config(cfg)),
       self(sys, true),
       sched(dynamic_cast<scheduler_type&>(sys.scheduler())) {
-    // Configure the clock to measure each batch item with 1us.
-    sched.clock().time_per_unit.emplace(caf::atom("batch"),
-                                        caf::timespan{1000});
     // Make sure the current time isn't 0.
     sched.clock().current_time += std::chrono::hours(1);
   }
@@ -755,7 +740,7 @@ public:
 
   /// Consume messages and trigger timeouts until no activity remains.
   /// @returns The total number of events, i.e., messages consumed and
-  ///          timeouts triggerd.
+  ///          timeouts triggered.
   size_t run() {
     return run_until([] { return false; });
   }
@@ -840,19 +825,19 @@ public:
   }
 
   template <class... Ts>
-  byte_buffer serialize(const Ts&... xs) {
-    byte_buffer buf;
+  caf::byte_buffer serialize(const Ts&... xs) {
+    caf::byte_buffer buf;
     caf::binary_serializer sink{sys, buf};
-    if (auto err = sink(xs...))
-      CAF_FAIL("serialization failed: " << sys.render(err));
+    if (!(sink.apply(xs) && ...))
+      CAF_FAIL("serialization failed: " << sink.get_error());
     return buf;
   }
 
   template <class... Ts>
-  void deserialize(const byte_buffer& buf, Ts&... xs) {
+  void deserialize(const caf::byte_buffer& buf, Ts&... xs) {
     caf::binary_deserializer source{sys, buf};
-    if (auto err = source(xs...))
-      CAF_FAIL("deserialization failed: " << sys.render(err));
+    if (!(source.apply(xs) && ...))
+      CAF_FAIL("deserialization failed: " << source.get_error());
   }
 
   template <class T>
@@ -950,9 +935,8 @@ T unbox(T* x) {
 /// Implementation detail for `TESTEE` and `VARARGS_TESTEE`.
 #define TESTEE_SCAFFOLD(tname)                                                 \
   struct tname##_state : testee_state_base<tname##_state> {                    \
-    static const char* name;                                                   \
+    static inline const char* name = #tname;                                   \
   };                                                                           \
-  const char* tname##_state::name = #tname;                                    \
   using tname##_actor = stateful_actor<tname##_state>
 
 /// Convenience macro for defining an actor named `tname`.
