@@ -1,6 +1,6 @@
 #pragma once
 
-#include "zeek-config.h"
+#include "zeek/zeek-config.h"
 #include <string>
 
 namespace zeek { class String; }
