@@ -2,8 +2,8 @@
 
 // SOCKS v4 analyzer.
 
-#include "analyzer/protocol/tcp/TCP.h"
-#include "analyzer/protocol/pia/PIA.h"
+#include "zeek/analyzer/protocol/tcp/TCP.h"
+#include "zeek/analyzer/protocol/pia/PIA.h"
 
 namespace binpac  {
    namespace SOCKS {
@@ -11,9 +11,9 @@ namespace binpac  {
    }
 }
 
-namespace analyzer { namespace socks {
+namespace zeek::analyzer::socks {
 
-class SOCKS_Analyzer : public tcp::TCP_ApplicationAnalyzer {
+class SOCKS_Analyzer final : public analyzer::tcp::TCP_ApplicationAnalyzer {
 public:
 	explicit SOCKS_Analyzer(Connection* conn);
 	~SOCKS_Analyzer() override;
@@ -33,8 +33,14 @@ protected:
 	bool orig_done;
 	bool resp_done;
 
-	pia::PIA_TCP *pia;
+	analyzer::pia::PIA_TCP *pia;
 	binpac::SOCKS::SOCKS_Conn* interp;
 };
 
-} } // namespace analyzer::* 
+} // namespace zeek::analyzer::socks
+
+namespace analyzer::socks {
+
+using SOCKS_Analyzer [[deprecated("Remove in v4.1. Use zeek::analyzer::socks::SOCKS_Analyzer.")]] = zeek::analyzer::socks::SOCKS_Analyzer;
+
+} // namespace analyzer::socks
