@@ -1,16 +1,15 @@
 #pragma once
 
-#include "events.bif.h"
+#include "zeek/analyzer/protocol/udp/UDP.h"
 
-#include "analyzer/protocol/udp/UDP.h"
+#include "analyzer/protocol/ssl/events.bif.h"
 
 namespace binpac { namespace DTLS { class SSL_Conn; } }
-
 namespace binpac { namespace TLSHandshake { class Handshake_Conn; } }
 
-namespace analyzer { namespace dtls {
+namespace zeek::analyzer::dtls {
 
-class DTLS_Analyzer : public analyzer::Analyzer {
+class DTLS_Analyzer final : public analyzer::Analyzer {
 public:
 	explicit DTLS_Analyzer(Connection* conn);
 	~DTLS_Analyzer() override;
@@ -22,7 +21,8 @@ public:
 	void EndOfData(bool is_orig) override;
 
 	void SendHandshake(uint16_t raw_tls_version, uint8_t msg_type, uint32_t length, const u_char* begin, const u_char* end, bool orig);
-
+	// Get the TLS version that the server chose. 0 if not yet known.
+	uint16_t GetNegotiatedVersion() const;
 
 	static analyzer::Analyzer* Instantiate(Connection* conn)
 		{ return new DTLS_Analyzer(conn); }
@@ -32,4 +32,10 @@ protected:
 	binpac::TLSHandshake::Handshake_Conn* handshake_interp;
 };
 
-} } // namespace analyzer::*
+} // namespace zeek::analyzer::dtls
+
+namespace analyzer::dtls {
+
+using DTLS_Analyzer [[deprecated("Remove in v4.1. Use zeek::analyzer::dtls::DTLS_Analyzer.")]] = zeek::analyzer::dtls::DTLS_Analyzer;
+
+} // namespace analyzer::dtls
