@@ -1,6 +1,6 @@
 #pragma once
 
-namespace analyzer { namespace tcp {
+namespace zeek::analyzer::tcp {
 
 class TCP_Flags {
 public:
@@ -14,13 +14,13 @@ public:
 	bool URG() const	{ return flags & TH_URG; }
 	bool PUSH() const	{ return flags & TH_PUSH; }
 
-	string AsString() const;
+	std::string AsString() const;
 
 protected:
 	u_char flags;
 };
 
-inline string TCP_Flags::AsString() const
+inline std::string TCP_Flags::AsString() const
 	{
 	char tcp_flags[10];
 	char* p = tcp_flags;
@@ -46,7 +46,11 @@ inline string TCP_Flags::AsString() const
 	*p++ = '\0';
 	return tcp_flags;
 	}
-}
 
+} // namespace zeek::analyzer::tcp
 
-}
+namespace analyzer::tcp {
+
+using TCP_Flags [[deprecated("Remove in v4.1. Use zeek::analyzer::tcp::TCP_Flags.")]] = zeek::analyzer::tcp::TCP_Flags;
+
+} // namespace analyzer::tcp
